<template>
  <div class="page">
    <div class="content">
      <div class="searchBox">
        <div class="search">
          <span></span>
          <input
            type="text"
            placeholder="请输入新生犬登记卡编号"
            @blur="getVal($event, 'birthCerRegCode')"
          />
        </div>
        <div class="search">
          <span></span>
          <input
            type="text"
            placeholder="请输入授权码"
            @blur="getVal($event, 'snCode')"
          />
        </div>
        <div class="find_btn_box" @click="getTransferSearch()">
          <div class="find_btn">查找</div>
        </div>
      </div>
      <div class="list">
        <div class="list_box" v-if="item != null">
          <div class="item_1_box">
            <div class="rectangle"></div>
            <div class="item_1">详情</div>
          </div>
          <div class="item_2_box">
            <div class="item_2">
              繁殖人：<span>{{ item.transferorMemberName }}</span>
            </div>
            <div class="item_2">
              犬名：<span>{{ item.dogName }}</span>
            </div>
            <div class="item_2">
              犬种：<span>{{ item.dogBreedDesc }}</span>
            </div>
            <div class="item_2">
              芯片号：<span>{{ item.identificationFlag }}</span>
            </div>
            <div class="item_2">
              出生日期：<span>{{ item.dogBirthdayDesc }}</span>
            </div>
            <div class="item_2">
              性别：<span>{{ item.dogGenderDesc }}</span>
            </div>
            <div class="item_2">
              毛色：<span>{{ item.colorFlagDesc }}</span>
            </div>
          </div>
        </div>
        <div class="tips">
          <p>温馨提示：</p>
          <p>
            《新生犬身份识别登记卡》仅作为幼犬的出生证明登记使用，如需体现犬只血系请升级为有效会员后申请办理《纯血犬血统证书》，并交纳相关费用。
          </p>
        </div>
      </div>
    </div>
    <div class="next_btn_box">
      <div class="next_btn" @click="openApplyNext()">下一步</div>
    </div>
  </div>
</template>

<script>
import { transferSearch } from "@/request/api";
import { Toast } from "vant";
export default {
  data() {
    return {
      birthCerRegCode: "",
      snCode: "",
      item: null,

      screenHeight: document.documentElement.clientHeight, // 这里是给到了一个默认值
      originHeight: document.documentElement.clientHeight, // 默认高度在watch里拿来做比较
      isOriginHei: true,
    };
  },
  created() {
    let This = this;
    window.onresize = () => {
      return (() => {
        This.screenHeight = document.documentElement.clientHeight;
      })();
    };
  },
  watch: {
    screenHeight(val) {
      // 判断软键盘弹出，收起
      if (this.originHeight - val > 50) {
        // 键盘弹出
        this.isOriginHei = false;
      } else {
        // 键盘收起
        this.isOriginHei = true;
      }
    },
  },
  mounted() {},
  methods: {
    // 获取输入
    getVal(e, type) {
      this[type] = e.target.value.replace(/ /g, "");
    },
    //查询
    getTransferSearch() {
      if (this.birthCerRegCode == "") {
        Toast("请输入新生犬登记卡编号");
        return false;
      }
      if (this.snCode == "") {
        Toast("请输入授权码");
        return false;
      }
      Toast.loading({
        message: "加载中",
        forbidClick: true,
        duration: 0,
      });
      transferSearch(
        {
          birthCerRegCode: this.birthCerRegCode,
          snCode: this.snCode,
        },
      ).then((res) => {
        if (res.rc == "0") {
          if (res.data != null) {
            this.item = res.data;
          } else {
            Toast(res.msg);
          }
        } else {
          Toast(res.msg);
        }
      });
    },
    //下一步
    openApplyNext() {
      if (this.item != null) {
        if (
          this.item.birthCerRegCode == this.birthCerRegCode
          // && this.item.snCode == this.snCode
        ) {
          sessionStorage.setItem(
            "transferApplyDetail",
            JSON.stringify(this.item)
          );
          this.$router.push({ name: "transferApplyConfirm" });
        } else {
          Toast("输入与查询的犬只信息不一致，请重新查询");
        }
      } else {
        Toast("请查询后点击下一步");
      }
    },
  },
};
</script>

<style scoped>
.page {
  min-height: 100vh;
  background-color: #f5f5f5;
}
.content {
  padding-bottom: 2.02rem;
}
.searchBox {
  padding: 0.1rem 0.1rem;
  background-color: #fff;
}
.search {
  border-radius: 0.35rem;
  margin: 0.4rem;
  background: #edeeee;
  padding: 0.16rem 2.14rem 0.16rem 0.88rem;
  box-sizing: border-box;
  position: relative;
  font-size: 0.28rem;
  font-weight: 400;
  color: #a8a8a8;
  line-height: 0.4rem;
  overflow: hidden;
}
.search span {
  height: 0.33rem;
  width: 0.32rem;
  background: url(../../assets/search.png) center center no-repeat;
  background-size: 100% 100%;
  position: absolute;
  top: 50%;
  left: 0.5rem;
  margin-top: -0.16rem;
}

.find_btn_box {
  display: flex;
  justify-content: center;
  margin-bottom: 0.4rem;
}
.find_btn {
  width: 4rem;
  line-height: 0.66rem;
  text-align: center;
  border-radius: 0.49rem;
  color: #fff;
  background: #29adfe;
  font-size: 0.3rem;
  box-sizing: border-box;
}

.list {
  padding: 0.1rem;
  margin-top: 0.1rem;
}
.list_box {
  border-radius: 0.1rem;
  background: #fff;
  border: 1px solid #add4ff;
}

.list_box .item_1_box {
  display: flex;
  align-items: center;
  background-color: #f2f9ff;
  border-top-left-radius: 0.1rem;
  border-top-right-radius: 0.1rem;
  padding: 0.1rem 0;
}
.list_box .rectangle {
  height: 0.3rem;
  width: 0.1rem;
  background: url(../../assets/rectangle.png) center center no-repeat;
  background-size: 100% 100%;
  margin: 0.1rem 0.1rem 0.1rem 0.2rem;
}
.list_box .item_1 {
  width: 100%;
  font-size: 0.28rem;
  line-height: 0.4rem;
  color: #0a2433;
}

.list_box .item_2_box {
  padding: 0.2rem 0.2rem 0.5rem 0.2rem;
}
.list_box .item_2_box .item_2 {
  font-size: 0.26rem;
  color: #999999;
  line-height: 0.3rem;
  padding: 0.3rem 0 0.2rem;
  border-bottom: 0.02rem solid #d7eaff;
}
.tips {
  font-size: 0.28rem;
  color: #ff6118;
  padding: 0.2rem;
  background: #f5f5f5;
}
.next_btn_box {
  position: fixed;
  bottom: 1rem;
  box-sizing: border-box;
  padding: 0 0.75rem;
}
.next_btn {
  width: 6rem;
  line-height: 0.88rem;
  text-align: center;
  border-radius: 0.49rem;
  color: #fff;
  background: #29adfe;
  font-size: 0.32rem;
  box-sizing: border-box;
}
</style>